"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getChapterCustomFields = exports.getSlideCustomFields = exports.normalizeStructureV1Chapters = exports.normalizeStructureV1Subslides = exports.flatChapterContent = exports.getChapterSlidesFromNested = exports.getNormalizedChapterEntity = exports.getNormalizedSlideEntity = exports.normalizeEntityForStructureV1 = exports.nestedSlideHasNoSubslides = exports.isSubslide = exports.getFiltersList = exports.getDefinitelyArchivedSlides = exports.listIncludesSlide = exports.getHiddenSlides = exports.getNormalizedChapters = exports.getSlidesWithSubslides = exports.getAllContent = exports.normalizeChapter = exports.normalizeSlide = exports.normalizeEntity = void 0;
const interfaces_1 = require("../types/interfaces");
const types_1 = require("../types/types");
function normalizeEntity(entity, entityType) {
    if (typeof entity === 'string') {
        return {
            [entityType]: entity,
            hidden: false
        };
    }
    return entity;
}
exports.normalizeEntity = normalizeEntity;
function normalizeSlide(entity) {
    return normalizeEntity(entity, types_1.EntityType.Slide);
}
exports.normalizeSlide = normalizeSlide;
function normalizeChapter(entity) {
    return normalizeEntity(entity, types_1.EntityType.Chapter);
}
exports.normalizeChapter = normalizeChapter;
function getAllContent(structure) {
    const chaptersId = Object.keys(structure.chapters);
    const chaptersContent = chaptersId
        .flatMap(chapterId => structure.chapters[chapterId].content.map(entity => normalizeSlide(entity)));
    return chaptersContent;
}
exports.getAllContent = getAllContent;
function getSlidesWithSubslides(structure) {
    return getAllContent(structure).filter(slide => normalizeSlide(slide).subslides);
}
exports.getSlidesWithSubslides = getSlidesWithSubslides;
function getNormalizedChapters(structure) {
    const chaptersId = Object.keys(structure.chapters);
    return chaptersId.map(chapterId => {
        return [
            chapterId,
            structure.chapters[chapterId].content
                .map(slideEntity => normalizeSlide(slideEntity))
        ];
    });
}
exports.getNormalizedChapters = getNormalizedChapters;
function getHiddenSlides(structure) {
    const slides = getAllContent(structure);
    const hiddenSlides = slides.filter(slide => slide.hidden);
    hiddenSlides.push(...(getSlidesWithSubslides(structure)
        .flatMap(slide => slide.subslides)
        .flatMap((subslide) => normalizeSlide(subslide))
        .filter(subslide => subslide.hidden)));
    return hiddenSlides;
}
exports.getHiddenSlides = getHiddenSlides;
function listIncludesSlide(list, slideId) {
    return list.some(slideEntity => (slideEntity.slide === slideId));
}
exports.listIncludesSlide = listIncludesSlide;
function getDefinitelyArchivedSlides(structure) {
    return structure.archivedSlides ?
        structure.archivedSlides.map(slideEntity => normalizeSlide(slideEntity)) :
        [];
}
exports.getDefinitelyArchivedSlides = getDefinitelyArchivedSlides;
function getFiltersList(types) {
    if (types) {
        const activeFilters = Object.entries(types).filter((filter) => filter[1]);
        return activeFilters.map((filter) => filter[0]);
    }
    return;
}
exports.getFiltersList = getFiltersList;
function isSubslide(nestedSlidesData, slideId) {
    const subslidesList = getSubslidesList(nestedSlidesData);
    return subslidesList.includes(slideId);
}
exports.isSubslide = isSubslide;
function getSubslidesList(nestedSlidesData) {
    return nestedSlidesData
        .filter(nestedSlide => nestedSlide.subslides.length)
        .flatMap(nestedSlide => nestedSlide.subslides)
        .map(subslide => subslide.id);
}
function nestedSlideHasNoSubslides(nestedSlide) {
    return !nestedSlide.subslides || !nestedSlide.subslides.length;
}
exports.nestedSlideHasNoSubslides = nestedSlideHasNoSubslides;
function normalizeEntityForStructureV1(entity) {
    if (entity.type === interfaces_1.StructureApi.SlideType.Hidden) {
        return `!${entity.id}`;
    }
    return entity.id;
}
exports.normalizeEntityForStructureV1 = normalizeEntityForStructureV1;
function getNormalizedSlideEntity(entity) {
    if (entity.startsWith('!')) {
        return {
            slide: entity.replace('!', ''),
            hidden: true
        };
    }
    return entity;
}
exports.getNormalizedSlideEntity = getNormalizedSlideEntity;
function getNormalizedChapterEntity(entity) {
    if (entity.startsWith('!')) {
        return {
            chapter: entity.replace('!', ''),
            hidden: true
        };
    }
    return entity;
}
exports.getNormalizedChapterEntity = getNormalizedChapterEntity;
function getChapterSlidesFromNested(nestedSlidesWithoutSubslides, chapterData) {
    return nestedSlidesWithoutSubslides
        .filter(nestedSlide => nestedSlide.chapter?.id === chapterData.id)
        .map(nestedSlide => {
        return nestedSlide.type === interfaces_1.StructureApi.SlideType.Hidden ? `!${nestedSlide.id}` : nestedSlide.id;
    });
}
exports.getChapterSlidesFromNested = getChapterSlidesFromNested;
function flatChapterContent(chapterContent) {
    return chapterContent.flatMap(slideEntity => {
        if (typeof slideEntity !== 'string' && slideEntity.slide) {
            const slide = slideEntity.slide;
            const subslides = slideEntity.subslides;
            return subslides ? [slide, ...subslides] : [slide];
        }
        return slideEntity;
    });
}
exports.flatChapterContent = flatChapterContent;
function normalizeStructureV1Subslides(slides) {
    const rawSlides = Object.entries(slides).map(slideEntry => {
        const slideData = slideEntry[1];
        if (slideData.subslides) {
            slideData.subslides = slideData.subslides.map(subslideName => {
                if (typeof subslideName === 'string') {
                    return getNormalizedSlideEntity(subslideName);
                }
                return subslideName;
            });
        }
        return [slideEntry[0], slideData];
    });
    return Object.fromEntries(rawSlides);
}
exports.normalizeStructureV1Subslides = normalizeStructureV1Subslides;
function normalizeStructureV1Chapters(structure) {
    const chapters = structure.chapters;
    const rawChapters = Object.entries(chapters).map(chapterEntry => {
        const { content } = chapterEntry[1];
        const normalizedContent = content.map(slideName => {
            const normalizedSlide = getNormalizedSlideEntity(slideName);
            return normalizedSlide;
        });
        const normalizedChapterData = {
            name: chapterEntry[1].name,
            content: normalizedContent,
            ...getChapterCustomFields(structure, chapterEntry[0])
        };
        return [chapterEntry[0], normalizedChapterData];
    });
    return Object.fromEntries(rawChapters);
}
exports.normalizeStructureV1Chapters = normalizeStructureV1Chapters;
function getSlideCustomFields(structure, slideId) {
    const slide = structure.slides[slideId];
    if (!slide) {
        return {};
    }
    const { name, template, ...customFields } = slide;
    return customFields || {};
}
exports.getSlideCustomFields = getSlideCustomFields;
function getChapterCustomFields(structure, chapterId) {
    const chapter = structure.chapters[chapterId];
    if (!chapter) {
        return {};
    }
    const { name, content, ...customFields } = chapter;
    return customFields || {};
}
exports.getChapterCustomFields = getChapterCustomFields;
//# sourceMappingURL=index.js.map